@@ -15,18 +15,18 @@
 # limitations under the License.
 # ============================================================================
 # Author: Nghia T. Vo
-# E-mail: algotomography@gmail.com
+# E-mail:  
 # Description: Python implementations of postprocessing techniques.
 # Contributors:
 # ============================================================================
 
 """
 Module of methods in the postprocessing stage:
-- Get statistical information of reconstructed images or a dataset.
-- Downsample 2D, 3D array, or a dataset.
-- Rescale 2D, 3D array or a dataset to 8-bit or 16-bit data-type.
-- Removing ring artifacts in a reconstructed image by transform back and forth
-between the polar coordinates and the Cartesian coordinates.
+    - Get statistical information of reconstructed images or a dataset.
+    - Downsample 2D, 3D array, or a dataset.
+    - Rescale 2D, 3D array or a dataset to 8-bit or 16-bit data-type.
+    - Removing ring artifacts in a reconstructed image by transform back and
+      forth between the polar coordinates and the Cartesian coordinates.
 """
 
 import os
@@ -37,7 +37,7 @@ import algotom.io.loadersaver as losa
 import algotom.prep.removal as remo
 
 
-def get_statical_information(mat, percentile=(5, 95), denoise=False):
+def get_statical_information(mat, percentile=(1, 99), denoise=False):
     """
     Get statical information of an image.
 
@@ -80,7 +80,7 @@ def get_statical_information(mat, percentile=(5, 95), denoise=False):
     return gmin, gmax, min_percent, max_percent, mean, median, variance
 
 
-def get_statical_information_dataset(input_, percentile=(5, 95), skip=5,
+def get_statical_information_dataset(input_, percentile=(1, 99), skip=5,
                                      denoise=False, key_path=None):
     """
     Get statical information of a dataset. This can be a folder of tif files,
@@ -220,7 +220,7 @@ def downsample_dataset(input_, output, cell_size, method="mean", key_path=None):
     """
     if output is not None:
         file_base, file_ext = os.path.splitext(output)
-        if file_ext is not "":
+        if file_ext != "":
             file_base = os.path.dirname(output)
         if os.path.exists(file_base):
             raise ValueError("Folder exists!!! Please choose another path!!!")
@@ -247,15 +247,16 @@ def downsample_dataset(input_, output, cell_size, method="mean", key_path=None):
         if (depth_dsp != 0) and (height_dsp != 0) and (width_dsp != 0):
             if output is not None:
                 file_base, file_ext = os.path.splitext(output)
-                if file_ext is not "":
+                if file_ext != "":
                     if not (file_ext == '.hdf' or file_ext == '.h5'
                             or file_ext == ".nxs"):
                         raise ValueError(
                             "File extension must be hdf, h5, or nxs")
-                output = file_base + file_ext
-                data_out = losa.open_hdf_stream(
-                    output, (depth_dsp, height_dsp, width_dsp),
-                    key_path="downsample/data", overwrite=False)
+                    else:
+                        output = file_base + file_ext
+                        data_out = losa.open_hdf_stream(
+                            output, (depth_dsp, height_dsp, width_dsp),
+                            key_path="downsample/data", overwrite=False)
             data_dsp = []
             for i in range(0, depth, cell_size[0]):
                 if (i + cell_size[0]) > depth:
@@ -274,7 +275,7 @@ def downsample_dataset(input_, output, cell_size, method="mean", key_path=None):
                     if output is None:
                         data_dsp.append(mat_dsp[0])
                     else:
-                        if file_ext is "":
+                        if file_ext == "":
                             out_name = "0000" + str(num)
                             losa.save_image(
                                 output + "/img_" + out_name[-5:] + ".tif",
@@ -311,15 +312,16 @@ def downsample_dataset(input_, output, cell_size, method="mean", key_path=None):
                     dsp_method(dsp_method(input_, axis=-1), axis=1), axis=2)
             else:
                 file_base, file_ext = os.path.splitext(output)
-                if file_ext is not "":
+                if file_ext != "":
                     if not (file_ext == '.hdf' or file_ext == '.h5'
                             or file_ext == ".nxs"):
                         raise ValueError(
                             "File extension must be hdf, h5, or nxs")
-                    output = file_base + file_ext
-                    data_out = losa.open_hdf_stream(
-                        output, (depth_dsp, height_dsp, width_dsp),
-                        key_path="downsample/data", overwrite=False)
+                    else:
+                        output = file_base + file_ext
+                        data_out = losa.open_hdf_stream(
+                            output, (depth_dsp, height_dsp, width_dsp),
+                            key_path="downsample/data", overwrite=False)
                 num = 0
                 for i in range(0, depth, cell_size[0]):
                     if (i + cell_size[0]) > depth:
@@ -332,7 +334,7 @@ def downsample_dataset(input_, output, cell_size, method="mean", key_path=None):
                                           cell_size[1], width_dsp, cell_size[2])
                         mat_dsp = dsp_method(dsp_method(
                             dsp_method(mat, axis=-1), axis=1), axis=2)
-                        if file_ext is not "":
+                        if file_ext != "":
                             data_out[num] = mat_dsp[0]
                         else:
                             out_name = "0000" + str(num)
@@ -405,7 +407,7 @@ def rescale_dataset(input_, output, nbit=16, minmax=None, skip=None,
     """
     if output is not None:
         file_base, file_ext = os.path.splitext(output)
-        if file_ext is not "":
+        if file_ext != "":
             file_base = os.path.dirname(output)
         if os.path.exists(file_base):
             raise ValueError("Folder exists!!! Please choose another path!!!")
@@ -423,7 +425,7 @@ def rescale_dataset(input_, output, nbit=16, minmax=None, skip=None,
             (gmin, gmax) = minmax
         if output is not None:
             file_base, file_ext = os.path.splitext(output)
-            if file_ext is not "":
+            if file_ext != "":
                 if not (file_ext == '.hdf' or file_ext == '.h5'
                         or file_ext == ".nxs"):
                     raise ValueError("File extension must be hdf, h5, or nxs")
@@ -445,7 +447,7 @@ def rescale_dataset(input_, output, nbit=16, minmax=None, skip=None,
                 data_res.append(mat)
             else:
                 file_base, file_ext = os.path.splitext(output)
-                if file_ext is "":
+                if file_ext == "":
                     out_name = "0000" + str(i)
                     losa.save_image(output + "/img_" + out_name[-5:] + ".tif",
                                     mat)
@@ -466,15 +468,14 @@ def rescale_dataset(input_, output, nbit=16, minmax=None, skip=None,
         if minmax is None:
             if skip is None:
                 skip = int(np.ceil(0.15 * depth))
-            (gmin, gmax) = get_statical_information_dataset(input_, skip=skip,
-                                                            key_path=key_path)[
-                           0:2]
+            f_alias = get_statical_information_dataset
+            (gmin, gmax) = f_alias(input_,skip=skip,key_path=key_path)[0:2]
         else:
             (gmin, gmax) = minmax
         data_res = []
         if output is not None:
             file_base, file_ext = os.path.splitext(output)
-            if file_ext is not "":
+            if file_ext != "":
                 if not (file_ext == '.hdf' or file_ext == '.h5'
                         or file_ext == ".nxs"):
                     raise ValueError("File extension must be hdf, h5, or nxs")
@@ -492,7 +493,7 @@ def rescale_dataset(input_, output, nbit=16, minmax=None, skip=None,
                 data_res.append(mat)
             else:
                 file_base, file_ext = os.path.splitext(output)
-                if file_ext is not "":
+                if file_ext != "":
                     data_out[i] = mat
                 else:
                     out_name = "0000" + str(i)
@@ -518,7 +519,7 @@ def remove_ring_based_fft(mat, u=20, n=8, v=1, sort=False):
     v : int
         Number of rows (* 2) to be applied the filter.
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
 
     Returns
     -------
@@ -547,7 +548,7 @@ def remove_ring_based_wavelet_fft(mat, level=5, size=1, wavelet_name="db9",
                                   sort=False):
     """
     Remove ring artifacts in a reconstructed image by combining the polar
-    transform and the wavelet-fft-based method (Ref. [1]).
+    transform and the wavelet-fft-based method (Ref. [1]_).
 
     Parameters
     ----------
@@ -560,7 +561,7 @@ def remove_ring_based_wavelet_fft(mat, level=5, size=1, wavelet_name="db9",
     wavelet_name : str
         Name of a wavelet. Search pywavelets API for a full list.
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
 
     Returns
     -------
