@@ -15,17 +15,17 @@
 # limitations under the License.
 # ============================================================================
 # Author: Nghia T. Vo
-# E-mail: algotomography@gmail.com
+# E-mail:  
 # Description: Python implementations of preprocessing techniques.
 # Contributors:
 # ============================================================================
 
 """
 Module of removal methods in the preprocessing stage:
-- Many methods for removing stripe artifact in a sinogram (<-> ring artifact
-in a reconstructed image).
-- A zinger removal method.
-- Blob removal methods.
+    - Many methods for removing stripe artifact in a sinogram (<-> ring artifact
+      in a reconstructed image).
+    - A zinger removal method.
+    - Blob removal methods.
 """
 
 import numpy as np
@@ -38,7 +38,7 @@ import algotom.util.utility as util
 def remove_stripe_based_sorting(sinogram, size=21, dim=1, **options):
     """
     Remove stripe artifacts in a sinogram using the sorting technique,
-    algorithm 3 in Ref. [1]. Angular direction is along the axis 0.
+    algorithm 3 in Ref. [1]_. Angular direction is along the axis 0.
 
     Parameters
     ----------
@@ -97,7 +97,7 @@ def remove_stripe_based_filtering(sinogram, sigma=3, size=21, dim=1, sort=True,
                                   **options):
     """
     Remove stripe artifacts in a sinogram using the filtering technique,
-    algorithm 2 in Ref. [1]. Angular direction is along the axis 0.
+    algorithm 2 in Ref. [1]_. Angular direction is along the axis 0.
 
     Parameters
     ----------
@@ -167,7 +167,7 @@ def remove_stripe_based_fitting(sinogram, order=2, sigma=10, sort=False,
                                 num_chunk=1, **options):
     """
     Remove stripe artifacts in a sinogram using the fitting technique,
-    algorithm 1 in Ref. [1]. Angular direction is along the axis 0.
+    algorithm 1 in Ref. [1]_. Angular direction is along the axis 0.
 
     Parameters
     ----------
@@ -238,7 +238,7 @@ def remove_stripe_based_fitting(sinogram, order=2, sigma=10, sort=False,
 def remove_large_stripe(sinogram, snr=3.0, size=51, drop_ratio=0.1, norm=True,
                         **options):
     """
-    Remove large stripe artifacts in a sinogram, algorithm 5 in Ref. [1].
+    Remove large stripe artifacts in a sinogram, algorithm 5 in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -312,10 +312,11 @@ def remove_large_stripe(sinogram, snr=3.0, size=51, drop_ratio=0.1, norm=True,
     return sinogram
 
 
-def remove_dead_stripe(sinogram, snr=3.0, size=51, residual=True):
+def remove_dead_stripe(sinogram, snr=3.0, size=51, residual=True,
+                       smooth_strength=10):
     """
     Remove unresponsive or fluctuating stripe artifacts in a sinogram,
-    algorithm 6 in Ref. [1]. Angular direction is along the axis 0.
+    algorithm 6 in Ref. [1]_. Angular direction is along the axis 0.
 
     Parameters
     ----------
@@ -327,6 +328,8 @@ def remove_dead_stripe(sinogram, snr=3.0, size=51, residual=True):
         Window size of the median filter.
     residual : bool, optional
         Removing residual stripes if True.
+    smooth_strength : int, optional
+        Window size of the uniform filter used to detect stripes.
 
     Returns
     -------
@@ -337,9 +340,10 @@ def remove_dead_stripe(sinogram, snr=3.0, size=51, residual=True):
     ----------
     .. [1] https://doi.org/10.1364/OE.26.028396
     """
-    sinogram = np.copy(sinogram)  # Make it mutable
-    (nrow, _) = sinogram.shape
-    sino_smooth = np.apply_along_axis(ndi.uniform_filter1d, 0, sinogram, 10)
+    sinogram = np.copy(sinogram)
+    (nrow, ncol) = sinogram.shape
+    sino_smooth = np.apply_along_axis(ndi.uniform_filter1d, 0, sinogram,
+                                      smooth_strength)
     list_diff = np.sum(np.abs(sinogram - sino_smooth), axis=0)
     list_diff_bck = ndi.median_filter(list_diff, size)
     nmean = np.mean(np.abs(list_diff_bck))
@@ -354,7 +358,7 @@ def remove_dead_stripe(sinogram, snr=3.0, size=51, residual=True):
     mat = sinogram[:, xlist]
     finter = interpolate.interp2d(xlist, ylist, mat, kind='linear')
     xlist_miss = np.where(list_mask > 0.0)[0]
-    if len(xlist_miss) > 0:
+    if (ncol // 3) > len(xlist_miss) > 0:
         sinogram[:, xlist_miss] = finter(xlist_miss, ylist)
     if residual is True:
         sinogram = remove_large_stripe(sinogram, snr, size)
@@ -365,7 +369,7 @@ def remove_all_stripe(sinogram, snr=3.0, la_size=51, sm_size=21, drop_ratio=0.1,
                       dim=1, **options):
     """
     Remove all types of stripe artifacts in a sinogram by combining algorithm
-    6, 5, 4, and 3 in Ref. [1]. Angular direction is along the axis 0.
+    6, 5, 4, and 3 in Ref. [1]_. Angular direction is along the axis 0.
 
     Parameters
     ----------
@@ -406,7 +410,7 @@ def remove_stripe_based_2d_filtering_sorting(sinogram, sigma=3, size=21, dim=1,
                                              **options):
     """
     Remove stripes using a 2D low-pass filter and the sorting-based technique,
-    algorithm in section 3.3.4 in Ref. [1].
+    algorithm in section 3.3.4 in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -440,7 +444,7 @@ def remove_stripe_based_2d_filtering_sorting(sinogram, sigma=3, size=21, dim=1,
 def remove_stripe_based_normalization(sinogram, sigma=15, num_chunk=1,
                                       sort=True, **options):
     """
-    Remove stripes using the method in Ref. [1].
+    Remove stripes using the method in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -452,7 +456,7 @@ def remove_stripe_based_normalization(sinogram, sigma=15, num_chunk=1,
     num_chunk : int
         Number of chunks of rows.
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
     options : dict, optional
         Use another smoothing 1D-filter rather than the Gaussian filter.
         E.g. options={"method": "median_filter", "para1": 21)}.
@@ -515,7 +519,7 @@ def remove_stripe_based_normalization(sinogram, sigma=15, num_chunk=1,
 def remove_stripe_based_regularization(sinogram, alpha=0.0005, num_chunk=1,
                                        apply_log=True, sort=True):
     """
-    Remove stripes using the method in Ref. [1].
+    Remove stripes using the method in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -529,7 +533,7 @@ def remove_stripe_based_regularization(sinogram, alpha=0.0005, num_chunk=1,
     apply_log : bool
         Apply the logarithm function to the sinogram if True.
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
 
     Returns
     -------
@@ -576,7 +580,7 @@ def remove_stripe_based_regularization(sinogram, alpha=0.0005, num_chunk=1,
 
 def remove_stripe_based_fft(sinogram, u=20, n=8, v=1, sort=False):
     """
-    Remove stripes using the method in Ref. [1].
+    Remove stripes using the method in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -590,7 +594,7 @@ def remove_stripe_based_fft(sinogram, u=20, n=8, v=1, sort=False):
     v : int
         Number of rows (* 2) to be applied the filter.
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
 
     Returns
     -------
@@ -621,7 +625,7 @@ def remove_stripe_based_wavelet_fft(sinogram, level=5, size=1,
                                     wavelet_name="db9", window_name="gaussian",
                                     sort=False, **options):
     """
-    Remove stripes using the method in Ref. [1].
+    Remove stripes using the method in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -637,7 +641,7 @@ def remove_stripe_based_wavelet_fft(sinogram, level=5, size=1,
     window_name : str
         High-pass window. Two options: "gaussian" or "butter".
     sort : bool, optional
-        Apply sorting (Ref. [2]) if True.
+        Apply sorting (Ref. [2]_) if True.
 
     Returns
     -------
@@ -701,7 +705,7 @@ def remove_stripe_based_interpolation(sinogram, snr=3.0, size=51,
                                       drop_ratio=0.1, norm=True, kind="linear",
                                       **options):
     """
-    Combination of algorithm 4, 5, and 6 in Ref. [1].
+    Combination of algorithm 4, 5, and 6 in Ref. [1]_.
     Angular direction is along the axis 0.
 
     Parameters
@@ -833,7 +837,7 @@ def select_zinger(mat, max_size):
 
 def remove_zinger(mat, threshold, size=2):
     """
-    Remove zinger using the method in Ref. [1], working on a projection image
+    Remove zinger using the method in Ref. [1]_, working on a projection image
     or sinogram image.
 
     Parameters
@@ -874,7 +878,7 @@ def remove_zinger(mat, threshold, size=2):
 
 def generate_blob_mask(flat, size, snr):
     """
-    Generate a binary mask of blobs from a flat-field image (Ref. [1]).
+    Generate a binary mask of blobs from a flat-field image (Ref. [1]_).
 
     Parameters
     ----------
@@ -911,7 +915,7 @@ def generate_blob_mask(flat, size, snr):
 def remove_blob_1d(sino_1d, mask_1d):
     """
     Remove blobs in one row of a sinogram, e.g. for a helical scan as shown in
-    Ref. [1].
+    Ref. [1]_.
 
     Parameters
     ----------
