@@ -15,23 +15,22 @@
 # limitations under the License.
 # ============================================================================
 # Author: Nghia T. Vo
-# E-mail: algotomography@gmail.com
+# E-mail:  
 # Description: Python implementations of FFT-based reconstruction methods
 # Contributors:
 # ============================================================================
 
 """
 Module of FFT-based reconstruction methods in the reconstruction stage:
-- Filtered back-projection (FBP) method for GPU (using numba and cuda) and CPU.
-- Direct Fourier inversion (DFI) method.
-- Wrapper for Astra Toolbox reconstruction (optional)
-- Wrapper for Tomopy-gridrec reconstruction (optional)
+    - Filtered back-projection (FBP) method for GPU (using numba and cuda) and CPU.
+    - Direct Fourier inversion (DFI) method.
+    - Wrapper for Astra Toolbox reconstruction (optional)
+    - Wrapper for Tomopy-gridrec reconstruction (optional)
 """
 
 import math
 import numpy as np
-from numba import cuda
-from numba import jit
+from numba import jit, cuda
 from scipy import signal
 from scipy.ndimage import shift
 import numpy.fft as fft
@@ -370,8 +369,8 @@ def dfi_reconstruction(sinogram, center, angles=None, ratio=1.0,
                        apply_log=True):
     """
     Apply the DFI (direct Fourier inversion) reconstruction method to a
-    sinogram image (Ref. [1]). The method is a practical and direct
-    implementation of the Fourier slice theorem (Ref. [2]).
+    sinogram image (Ref. [1]_). The method is a practical and direct
+    implementation of the Fourier slice theorem (Ref. [2]_).
 
     Parameters
     ----------
@@ -422,7 +421,7 @@ def dfi_reconstruction(sinogram, center, angles=None, ratio=1.0,
         sino_360 = np.vstack((sinogram[: nrow - 1], np.fliplr(sinogram)))
         sinogram = shift(sino_360, (b_ang / step, 0), mode='wrap')[:nrow]
         if angles[-1] < angles[0]:
-            sinogram = np.fliplr(sinogram)
+            sinogram = np.flipud(np.fliplr(sinogram))
     num_pad = int(pad_rate * ncol1)
     sinogram = np.pad(sinogram, ((0, 0), (num_pad, num_pad)), mode=pad_mode)
     ncol2 = sinogram.shape[1]
