@@ -15,7 +15,7 @@
 # limitations under the License.
 # ============================================================================
 # Author: Nghia T. Vo
-# E-mail: algotomography@gmail.com
+# E-mail:  
 # Description: Simulation methods
 # Contributors:
 # ============================================================================
@@ -23,10 +23,10 @@
 
 """
 Module of simulation methods:
-1- Methods for designing a customized 2D phantom.
-2- Method for calculating a sinogram of a phantom based on the Fourier
-   slice theorem.
-3- Methods for adding artifacts to a simulated sinogram.
+    - Methods for designing a customized 2D phantom.
+    - Method for calculating a sinogram of a phantom based on the Fourier
+      slice theorem.
+    - Methods for adding artifacts to a simulated sinogram.
 """
 
 import numpy as np
@@ -255,9 +255,11 @@ def make_face_phantom(size):
     """
     half = size // 2
     mask = np.zeros((size, size), dtype=np.float32)
-    face1 = make_elliptic_mask(size, 0.0, (size / 1.3, 0.98 * size), 0.0)
+    ratio1 = 0.95 if size > 64 else 0.9
+    ratio2 = 0.91 if size > 64 else 0.86
+    face1 = make_elliptic_mask(size, 0.0, (size / 1.3, ratio1 * size), 0.0)
     face2 = -0.6 * make_elliptic_mask(size, (0.0, -0.01 * size),
-                                      (0.94 * size / 1.3, 0.94 * size), 0.0)
+                                      (ratio2 * size / 1.3, ratio2 * size), 0.0)
     face = face1 + face2
     x_rat_eye = 0.3
     y_rat_eye = 0.4
@@ -321,7 +323,7 @@ def make_face_phantom(size):
 def make_sinogram(mat, angles, pad_rate=0.5, pad_mode="edge"):
     """
     Create a sinogram (series of 1D projections) from a 2D image based on the
-    Fourier slice theorem (Ref. [1]).
+    Fourier slice theorem (Ref. [1]_).
 
     Parameters
     ----------
@@ -409,7 +411,7 @@ def add_stripe_artifact(sinogram, size, position, strength_ratio=0.2,
         To define the strength of the artifact. The value is in the range of
         [0.0, 1.0].
     stripe_type : {"partial", "full", "dead", "fluctuating"}
-        Type of stripe as classified in Ref. [1].
+        Type of stripe as classified in Ref. [1]_.
 
     Returns
     -------
