@@ -15,37 +15,39 @@
 # limitations under the License.
 # ============================================================================
 # Author: Nghia T. Vo
-# E-mail: algotomography@gmail.com
+# E-mail:  
 # Description: Utility methods
 # Contributors:
 # ============================================================================
 
 """
 Module of utility methods:
-1- Methods for parallel computing, geometric transformation, masking.
-2- Methods for customizing stripe/ring removal methods
-    2.1  - sort_forward
-    2.2  - sort_backward
-    2.3  - separate_frequency_component
-    2.4  - generate_fitted_image
-    2.5  - detect_stripe
-    2.6  - calculate_regularization_coefficient
-    2.7  - make_2d_butterworth_window
-    2.8  - make_2d_damping_window
-    2.9  - apply_wavelet_decomposition
-    2.10 - apply_wavelet_reconstruction
-    2.11 - apply_filter_to_wavelet_component
-    2.12 - interpolate_inside_stripe
-    2.13 - transform_slice_forward
-    2.14 - transform_slice_backward
-3- Customized smoothing filters:
-    3.1 - apply_gaussian_filter (in the Fourier space)
-    3.2 - apply_regularization_filter
-4- Methods for grid scans:
-    4.1  - detect_sample
-    4.2  - fix_non_sample_areas
-    4.3  - locate_slice
-    4.4  - locate_slice_chunk
+    - Methods for parallel computing, geometric transformation, masking.
+    - Methods for customizing stripe/ring removal methods
+        + sort_forward
+        + sort_backward
+        + separate_frequency_component
+        + generate_fitted_image
+        + detect_stripe
+        + calculate_regularization_coefficient
+        + make_2d_butterworth_window
+        + make_2d_damping_window
+        + apply_wavelet_decomposition
+        + apply_wavelet_reconstruction
+        + apply_filter_to_wavelet_component
+        + interpolate_inside_stripe
+        + transform_slice_forward
+        + transform_slice_backward
+    - Customized smoothing filters:
+        + apply_gaussian_filter (in the Fourier space)
+        + apply_regularization_filter
+    - Methods for grid scans:
+        + detect_sample
+        + fix_non_sample_areas
+        + locate_slice
+        + locate_slice_chunk
+    - Methods for speckle-based tomography
+        + generate_spiral_positions
  """
 
 import sys
@@ -78,7 +80,7 @@ def apply_method_to_multiple_sinograms(data, method, para, ncore=None):
     para : list
         Parameters of the method. e.g. [21, 1]
     ncore: int or None
-        Number of cores used for computing. Automatically selected if None.
+        Number of cpu-cores used for computing. Automatically selected if None.
 
     Returns
     -------
@@ -109,7 +111,7 @@ def apply_method_to_multiple_sinograms(data, method, para, ncore=None):
     return data_out
 
 
-def mapping(mat, xmat, ymat, order=1, mode="reflect"):
+def mapping(mat, x_mat, y_mat, order=1, mode="reflect"):
     """
     Apply a geometric transformation to a 2D array
 
@@ -117,9 +119,9 @@ def mapping(mat, xmat, ymat, order=1, mode="reflect"):
     ----------
     mat : array_like
         2D array.
-    xmat : array_like
+    x_mat : array_like
         2D array of the x-coordinates.
-    ymat : array_like
+    y_mat : array_like
         2D array of the y-coordinates.
     order : int, optional
         The order of the spline interpolation, default is 1.
@@ -133,9 +135,9 @@ def mapping(mat, xmat, ymat, order=1, mode="reflect"):
     array_like
         2D array.
     """
-    coords = np.vstack((np.ndarray.flatten(ymat), np.ndarray.flatten(xmat)))
+    coords = np.vstack((np.ndarray.flatten(y_mat), np.ndarray.flatten(x_mat)))
     mat = ndi.map_coordinates(mat, coords, order=order, mode=mode)
-    return mat.reshape(xmat.shape)
+    return mat.reshape(x_mat.shape)
 
 
 def make_circle_mask(width, ratio):
@@ -316,7 +318,7 @@ def generate_fitted_image(mat, order, axis=0, num_chunk=1):
 
 def detect_stripe(list_data, snr):
     """
-    Locate stripe positions using Algorithm 4 in Ref. [1]
+    Locate stripe positions using Algorithm 4 in Ref. [1]_
 
     Parameters
     ----------
@@ -336,11 +338,11 @@ def detect_stripe(list_data, snr):
     """
     npoint = len(list_data)
     list_sort = np.sort(list_data)
-    xlist = np.arange(0, npoint, 1.0)
+    x_list = np.arange(0, npoint, 1.0)
     ndrop = np.int16(0.25 * npoint)
-    (slope, intercept) = np.polyfit(xlist[ndrop:-ndrop - 1],
+    (slope, intercept) = np.polyfit(x_list[ndrop:-ndrop - 1],
                                     list_sort[ndrop:-ndrop - 1], 1)
-    y_end = intercept + slope * xlist[-1]
+    y_end = intercept + slope * x_list[-1]
     noise_level = np.abs(y_end - intercept)
     if noise_level == 0.0:
         raise ValueError("The method doesn't work on noise-free data. If you "
@@ -361,7 +363,7 @@ def detect_stripe(list_data, snr):
 def calculate_regularization_coefficient(width, alpha):
     """
     Calculate coefficients used for the regularization-based method.
-    Eq. (7) in Ref. [1].
+    Eq. (7) in Ref. [1]_.
 
     Parameters
     ----------
@@ -417,8 +419,8 @@ def make_2d_butterworth_window(width, height, u, v, n):
     """
     xcenter = np.ceil(width / 2.0) - 1.0
     ycenter = np.int16(np.ceil(height / 2.0) - 1)
-    xlist = np.arange(width) - xcenter
-    window = 1.0 / (1.0 + np.power(xlist / u, 2 * n))
+    x_list = np.arange(width) - xcenter
+    window = 1.0 / (1.0 + np.power(x_list / u, 2 * n))
     row1 = ycenter - np.int16(v)
     row2 = ycenter + np.int16(v) + 1
     window_2d = np.ones((height, width), dtype=np.float32)
@@ -448,11 +450,11 @@ def make_2d_damping_window(width, height, size, window_name="gaussian"):
         2D array of the window.
     """
     xcenter = np.ceil(width / 2.0) - 1.0
-    xlist = np.arange(width) - xcenter
+    x_list = np.arange(width) - xcenter
     if window_name == "butter":
-        window = 1.0 - 1.0 / (1.0 + np.power(xlist / size, 2))
+        window = 1.0 - 1.0 / (1.0 + np.power(x_list / size, 2))
     else:
-        window = 1.0 - np.exp(-xlist ** 2 / (2 * (size ** 2)))
+        window = 1.0 - np.exp(-x_list ** 2 / (2 * (size ** 2)))
     return np.tile(window, (height, 1))
 
 
@@ -532,13 +534,19 @@ def check_level(level, n_level):
             if 0 in level:
                 raise ValueError(
                     "Level is out of range: [1:{}]!".format(n_level))
+        elif isinstance(level, tuple):
+            level = [(i if (0 < i <= n_level) else 0) for i in level]
+            if 0 in level:
+                raise ValueError(
+                    "Level is out of range: [1:{}]!".format(n_level))
         else:
-            raise ValueError("Level-input is incorrect!")
+            raise ValueError("Level-input format is incorrect!")
     return level
 
 
 def apply_filter_to_wavelet_component(data, level=None, order=1,
-                                      method="gaussian_filter", para=[(1, 11)]):
+                                      method="gaussian_filter",
+                                      para=[(1, 11)]):
     """
     Apply a filter to a component of the wavelet decomposition of an image.
 
@@ -614,10 +622,10 @@ def interpolate_inside_stripe(mat, list_mask, kind="linear"):
     list_mask = np.copy(list_mask)
     list_mask[0:2] = 0.0
     list_mask[-2:] = 0.0
-    xlist = np.where(list_mask < 1.0)[0]
+    x_list = np.where(list_mask < 1.0)[0]
     ylist = np.arange(nrow)
-    zmat = mat[:, xlist]
-    finter = interpolate.interp2d(xlist, ylist, zmat, kind=kind)
+    zmat = mat[:, x_list]
+    finter = interpolate.interp2d(x_list, ylist, zmat, kind=kind)
     xlist_miss = np.where(list_mask > 0.0)[0]
     if len(xlist_miss) > 0:
         mat[:, xlist_miss] = finter(xlist_miss, ylist)
@@ -849,7 +857,7 @@ def apply_1d_regularizer(list_data, sijmat):
 
 def apply_regularization_filter(mat, alpha, axis=1, ncore=None):
     """
-    Apply a regularization filter using the method in Ref. [1].
+    Apply a regularization filter using the method in Ref. [1]_.
     Note that it's computationally costly.
 
     Parameters
@@ -861,7 +869,7 @@ def apply_regularization_filter(mat, alpha, axis=1, ncore=None):
     axis : int
         Axis along which to apply the filter.
     ncore: int or None
-        Number of cores used for computing. Automatically selected if None.
+        Number of cpu-cores used for computing. Automatically selected if None.
 
     Returns
     -------
@@ -923,7 +931,7 @@ def transform_1d_window_to_2d(win_1d):
 def detect_sample(sinogram, sino_type="180"):
     """
     To check if there is a sample in a sinogram using the "double-wedge"
-    property of the Fourier transform of the sinogram (Ref. [1]).
+    property of the Fourier transform of the sinogram (Ref. [1]_).
 
     Parameters
     ----------
@@ -1078,8 +1086,9 @@ def locate_slice(slice_idx, height, overlap_metadata):
         list_slices = [(np.arange(i * height, i * height + height) -
                         np.sum(overlap_list[0: i])) for i in range(g_nrow)]
     else:
-        list_slices = [(np.arange(i * height + height - 1, i * height - 1, -1) -
-                        np.sum(overlap_list[0: i])) for i in range(g_nrow)]
+        list_slices = [
+            (np.arange(i * height + height - 1, i * height - 1, -1) -
+             np.sum(overlap_list[0: i])) for i in range(g_nrow)]
     list_slices = np.asarray(list_slices)
     results = []
     for i, list1 in enumerate(list_slices):
@@ -1138,8 +1147,9 @@ def locate_slice_chunk(slice_start, slice_stop, height, overlap_metadata):
         list_slices = [(np.arange(i * height, i * height + height) -
                         np.sum(overlap_list[0: i])) for i in range(g_nrow)]
     else:
-        list_slices = [(np.arange(i * height + height - 1, i * height - 1, -1) -
-                        np.sum(overlap_list[0: i])) for i in range(g_nrow)]
+        list_slices = [
+            (np.arange(i * height + height - 1, i * height - 1, -1) -
+             np.sum(overlap_list[0: i])) for i in range(g_nrow)]
     list_slices = np.asarray(list_slices)
     results = []
     for i, list1 in enumerate(list_slices):
@@ -1203,3 +1213,41 @@ def locate_slice_chunk(slice_start, slice_stop, height, overlap_metadata):
         if len(result1) > 0:
             results.append(result1)
     return results
+
+
+def generate_spiral_positions(step, num_pos, height, width, spiral_shape=1.0):
+    """
+    Generate Fermat spiral positions. Unit is pixel.
+
+    Parameters
+    ----------
+    step : int
+        Step size in pixel. ~ 20-> 40
+    num_pos : int
+        Number of positions.
+    height: int
+        Height of the field of view (in pixel).
+    width: int
+        Width of the field of view (in pixel).
+    spiral_shape : float, optional
+        To define the spiral shape.
+
+    Returns
+    -------
+    array_like
+        2D array. List of (x,y) positions
+    """
+    positions = []
+    phi = 2.0 * np.pi * ((1.0 + np.sqrt(5)) / 2) + spiral_shape * np.pi
+    mid_hei = height // 2
+    mid_wid = width // 2
+    for i in range(num_pos):
+        r = 1.0 * step * np.sqrt(i)
+        x_pos = r * np.cos(i * phi)
+        y_pos = r * np.sin(i * phi)
+        if (np.abs(x_pos) > mid_wid) or (np.abs(y_pos) > mid_hei):
+            msg = "Calculated position is out of the field of view. " \
+                  "Please reduce the step!!!"
+            raise ValueError(msg)
+        positions.append([x_pos, y_pos])
+    return np.asarray(positions, dtype=np.float32)
